Exception: DatabasusRuby::ConfigurationError
- Defined in:
- lib/databasus_ruby/error.rb,
sig/databasus_ruby.rbs
Overview
Raised when the client is missing something it needs before it can talk to the API at all (an agent id, a workspace id, ...).
Raised when the client is missing something it needs before it can talk to the API at all (an agent id, a workspace id, ...).